@@ -322,3 +322,24 @@ void MainWindow::on_actionOpzioni_triggered()
     mOpzioni.setModal(true);
     mOpzioni.exec();
 }
+
+void MainWindow::on_down13_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d13.sh");
+    process.waitForFinished();
+}
+
+void MainWindow::on_stream13_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p13.sh");
+    process.waitForFinished();
+}
+
+void MainWindow::on_actionServizioPubblico_Online_triggered()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/official.sh");
+    process.waitForFinished();
+}
